@@ -1,5 +1,3 @@
-from aries_cloudcontroller.acapy_client import AcaPyClient
-
 from aries_cloudcontroller.api import (
     ActionMenuApi,
     BasicmessageApi,
@@ -32,7 +30,6 @@ from aries_cloudcontroller.api import (
 from aries_cloudcontroller.model import (
     AMLRecord,
     ActionMenuFetchResult,
-    AdminAPIMessageTracing,
     AdminConfig,
     AdminMediationDeny,
     AdminModules,
@@ -66,6 +63,8 @@ from aries_cloudcontroller.model import (
     CredDefValuePrimary,
     CredDefValueRevocation,
     CredInfoList,
+    CredRevIndyRecordsResult,
+    CredRevRecordDetailsResult,
     CredRevRecordResult,
     CredRevokedResult,
     Credential,
@@ -186,13 +185,13 @@ from aries_cloudcontroller.model import (
     QueryItem,
     RawEncoded,
     ReceiveInvitationRequest,
-    RegisterLedgerNymResponse,
     RemoveWalletRequest,
     ResolutionResult,
     RevRegCreateRequest,
     RevRegIssuedResult,
     RevRegResult,
     RevRegUpdateTailsFileUri,
+    RevRegWalletUpdatedResult,
     RevRegsCreated,
     RevokeRequest,
     RouteRecord,
@@ -219,6 +218,7 @@ from aries_cloudcontroller.model import (
     TransactionRecord,
     TxnOrCredentialDefinitionSendResult,
     TxnOrPublishRevocationsResult,
+    TxnOrRegisterLedgerNymResponse,
     TxnOrRevRegResult,
     TxnOrSchemaSendResult,
     UpdateWalletRequest,
@@ -242,6 +242,7 @@ from aries_cloudcontroller.model import (
     V10PresentationProblemReportRequest,
     V10PresentationProposalRequest,
     V10PresentationSendRequestRequest,
+    V10PresentationSendRequestToProposal,
     V20CredAttrSpec,
     V20CredBoundOfferRequest,
     V20CredExFree,
@@ -285,6 +286,7 @@ from aries_cloudcontroller.model import (
     V20PresRequestByFormat,
     V20PresSendRequestRequest,
     V20PresSpecByFormatRequest,
+    V20PresentationSendRequestToProposal,
     VCRecord,
     VCRecordList,
     VerifyRequest,
@@ -296,10 +298,8 @@ from aries_cloudcontroller.model import (
 )
 
 __all__ = [
-    "AcaPyClient",
     "AMLRecord",
     "ActionMenuFetchResult",
-    "AdminAPIMessageTracing",
     "AdminConfig",
     "AdminMediationDeny",
     "AdminModules",
@@ -333,6 +333,8 @@ __all__ = [
     "CredDefValuePrimary",
     "CredDefValueRevocation",
     "CredInfoList",
+    "CredRevIndyRecordsResult",
+    "CredRevRecordDetailsResult",
     "CredRevRecordResult",
     "CredRevokedResult",
     "Credential",
@@ -453,13 +455,13 @@ __all__ = [
     "QueryItem",
     "RawEncoded",
     "ReceiveInvitationRequest",
-    "RegisterLedgerNymResponse",
     "RemoveWalletRequest",
     "ResolutionResult",
     "RevRegCreateRequest",
     "RevRegIssuedResult",
     "RevRegResult",
     "RevRegUpdateTailsFileUri",
+    "RevRegWalletUpdatedResult",
     "RevRegsCreated",
     "RevokeRequest",
     "RouteRecord",
@@ -486,6 +488,7 @@ __all__ = [
     "TransactionRecord",
     "TxnOrCredentialDefinitionSendResult",
     "TxnOrPublishRevocationsResult",
+    "TxnOrRegisterLedgerNymResponse",
     "TxnOrRevRegResult",
     "TxnOrSchemaSendResult",
     "UpdateWalletRequest",
@@ -509,6 +512,7 @@ __all__ = [
     "V10PresentationProblemReportRequest",
     "V10PresentationProposalRequest",
     "V10PresentationSendRequestRequest",
+    "V10PresentationSendRequestToProposal",
     "V20CredAttrSpec",
     "V20CredBoundOfferRequest",
     "V20CredExFree",
@@ -552,6 +556,7 @@ __all__ = [
     "V20PresRequestByFormat",
     "V20PresSendRequestRequest",
     "V20PresSpecByFormatRequest",
+    "V20PresentationSendRequestToProposal",
     "VCRecord",
     "VCRecordList",
     "VerifyRequest",
